@@ -222,4 +222,13 @@ public class ComponentsDefine {
     public static final OfficialComponent GUAVA_EVENT_BUS = new OfficialComponent(123, "GuavaEventBus");
 
     public static final OfficialComponent APACHE_SHENYU = new OfficialComponent(127, "Apache-ShenYu");
+
+    public static final OfficialComponent HUTOOL = new OfficialComponent(128, "Hutool");
+
+    public static final OfficialComponent MICRONAUT = new OfficialComponent(131, "Micronaut");
+
+    public static final OfficialComponent NATS = new OfficialComponent(132, "Nats");
+
+    public static final OfficialComponent IMPALA_JDBC_DRIVER = new OfficialComponent(133, "Impala-jdbc-driver");
+
 }
